.. _aantallen:

AANTALLEN
#########

                                  2011 2012 2013 2014

Lastgeving tot IBS:               8521 8522 8813 8344

Machtiging voortzetting IBS:      7458 7377 7964 7886

Voorlopige machtiging:            5837 5937 6163 6183

Machtiging voortgezet verblijf:   3620 3705 3966 3992

Voorwaardelijke machtiging:       3689 4244 4699 5203
